summaryrefslogtreecommitdiff
path: root/clutter/clutter-scriptable.c
diff options
context:
space:
mode:
authorEmmanuele Bassi <ebassi@linux.intel.com>2011-02-15 11:50:26 +0000
committerEmmanuele Bassi <ebassi@linux.intel.com>2011-02-15 12:40:11 +0000
commit5c398c18ad68363e13c4be04c68f0d6e87d72393 (patch)
treef189ea350ee33441316f3e84041f54734ea9a8dc /clutter/clutter-scriptable.c
parent54a4511247bbec5330332971ea06e17af33839be (diff)
downloadclutter-5c398c18ad68363e13c4be04c68f0d6e87d72393.tar.gz
More ISO C90 warning fixes in Clutter
This time, in Clutter core. The ObjC standard library provides a type called 'id', which obviously requires any library to either drop the useful shadowed variable warning or stop using 'id' as a variable name. Yes, it's almost unbearably stupid. Well, at least it's not 'index' in string.h, or 'y2' in math.h.
Diffstat (limited to 'clutter/clutter-scriptable.c')
-rw-r--r--clutter/clutter-scriptable.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/clutter/clutter-scriptable.c b/clutter/clutter-scriptable.c
index 082aebade..501f1df24 100644
--- a/clutter/clutter-scriptable.c
+++ b/clutter/clutter-scriptable.c
@@ -63,9 +63,9 @@ clutter_scriptable_default_init (ClutterScriptableInterface *iface)
/**
* clutter_scriptable_set_id:
* @scriptable: a #ClutterScriptable
* @id: the #ClutterScript id of the object
*
* Sets @id as the unique Clutter script it for this instance of
* #ClutterScriptableIface.
*
* This name can be used by user interface designer applications to
@@ -76,20 +76,20 @@ clutter_scriptable_default_init (ClutterScriptableInterface *iface)
*/
void
clutter_scriptable_set_id (ClutterScriptable *scriptable,
- const gchar *id)
+ const gchar *id_)
{
ClutterScriptableIface *iface;
g_return_if_fail (CLUTTER_IS_SCRIPTABLE (scriptable));
- g_return_if_fail (id != NULL);
+ g_return_if_fail (id_ != NULL);
iface = CLUTTER_SCRIPTABLE_GET_IFACE (scriptable);
if (iface->set_id)
- iface->set_id (scriptable, id);
+ iface->set_id (scriptable, id_);
else
g_object_set_data_full (G_OBJECT (scriptable),
"clutter-script-id",
- g_strdup (id),
+ g_strdup (id_),
g_free);
}
@@ -63,9 +63,9 @@ clutter_scriptable_default_init (ClutterScriptableInterface *iface)
* clutter_scriptable_set_id:
* @scriptable: a #ClutterScriptable
- * @id: the #ClutterScript id of the object
+ * @id_: the #ClutterScript id of the object
*
@@ -63,9 +63,9 @@ clutter_scriptable_default_init (ClutterScriptableInterface *iface)
*
- * Sets @id as the unique Clutter script it for this instance of
+ * Sets @id_ as the unique Clutter script it for this instance of
* #ClutterScriptableIface.
*